@@ -1,19 +1,7 @@
 from nonebot.adapters.onebot.v11 import MessageSegment
-from nonebot.log import logger
-from .adapters.utils import adapter_selector
 from .image_generator import draw_b30, draw_recent, draw_user_best
 from io import BytesIO
-
-api_in_use = adapter_selector().upper()
-if api_in_use == "AUA":
-    logger.info("将使用ArcaeaUnlimitedApi")
-    from .adapters.aua.resolver import ApiResult
-    from .adapters.aua.api import get_user_best
-elif api_in_use == "ESTERTION":
-    logger.info("将使用EstertionApi")
-    from .adapters.estertion.resolver import ApiResult
-else:
-    logger.error("不支持的Api选项")
+from .AUA import get_user_best, get_user_b30, get_user_recent
 
 
 class UserArcaeaInfo:
@@ -27,14 +15,13 @@ class UserArcaeaInfo:
     async def draw_best30_image(arcaea_id: str):
         UserArcaeaInfo.querying.append(arcaea_id)
         try:
-            data = ApiResult()
-            await data.get_b30(arcaea_id=arcaea_id)
-            if data.retcode != 0:
+            data = await get_user_b30(arcaea_id=arcaea_id, overflow=10)
+            if data["status"] != 0:
                 UserArcaeaInfo.querying.remove(arcaea_id)
-                return data.message
+                return str(data["status"]) + ": " + data["message"]
             else:
                 UserArcaeaInfo.querying.remove(arcaea_id)
-                image = draw_b30(arcaea_id=arcaea_id, data=data)
+                image = draw_b30(data=data)
                 buffer = BytesIO()
                 image.save(buffer, "png")
                 return MessageSegment.image(buffer)
@@ -46,14 +33,13 @@ class UserArcaeaInfo:
     async def draw_recent_image(arcaea_id: str):
         UserArcaeaInfo.querying.append(arcaea_id)
         try:
-            data = ApiResult()
-            await data.get_recent(arcaea_id=arcaea_id)
-            if data.retcode != 0:
+            data = await get_user_recent(arcaea_id=arcaea_id)
+            if data["status"] != 0:
                 UserArcaeaInfo.querying.remove(arcaea_id)
-                return data.message
+                return str(data["status"]) + ": " + data["message"]
             else:
                 UserArcaeaInfo.querying.remove(arcaea_id)
-                image = draw_recent(arcaea_id=arcaea_id, data=data)
+                image = draw_recent(data=data)
                 buffer = BytesIO()
                 image.save(buffer, "png")
                 return MessageSegment.image(buffer)
@@ -70,7 +56,7 @@ class UserArcaeaInfo:
             )
             if data["status"] != 0:
                 UserArcaeaInfo.querying.remove(arcaea_id)
-                return data["message"]
+                return str(data["status"]) + ": " + data["message"]
             else:
                 UserArcaeaInfo.querying.remove(arcaea_id)
                 image = draw_user_best(data=data)
